@@ -30,7 +30,7 @@ parser.add_argument("-n", "--num-instances",
                     help="Instances that the operation affect",
                     action='store')
 parser.add_argument("-l", "--list",
-                    dest="list",
+                    dest="list_instances",
                     help="List all instances.",
                     action='store_true')
 parser.add_argument("-e", "--exec",
@@ -56,7 +56,7 @@ parser.add_argument("-w", "--wait",
 parser.add_argument("-i", "--input-file",
                     dest="input_file",
                     help="The name of the file to split.",
-                    action='store_true')
+                    action='store')
 parser.add_argument("-in", "--interactive",
                     dest="interactive",
                     help="Start interactive acido session.",
@@ -79,13 +79,12 @@ instances_outputs = {}
 def build_output(result):
     global instances_outputs
     instances_outputs[result[0]] = [result[1], result[2]]
-    print(instances_outputs)
 
 def exec_command(rg, cg, cont, command, max_retries, input_file):
     env = os.environ.copy()
     env["PATH"] = "/usr/sbin:/sbin:" + env["PATH"]
     # Kill tmux window
-    subprocess.Popen(["tmux", "kill-session", "-t", cont], env=env, stdout=subprocess.DEVNULL)
+    subprocess.Popen(["tmux", "kill-session", "-t", cont], env=env, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
     time.sleep(2)
     subprocess.Popen(["tmux", "new-session", "-d", "-s", cont], env=env)
     time.sleep(5)
@@ -394,7 +393,8 @@ class Acido(object):
                         number_of_containers += 1
 
             number_of_lines = [line.strip() for line in open(input_file, 'r').readlines()]
-            chunked_lines = int(number_of_lines / number_of_containers)
+            chunked_lines = int(len(number_of_lines) / number_of_containers)
+            print(good(f'Splitting into {number_of_containers} files.'))
             os.system(f'split -l {str(chunked_lines)} {input_file} /tmp/acido-input-')
         
             directory = os.fsencode('/tmp/')
@@ -404,7 +404,7 @@ class Acido(object):
             for file in os.listdir(directory):
                 filename = os.fsdecode(file)
                 if filename.startswith("acido-input"): 
-                    input_files.append(self.save_input(filename))
+                    input_files.append(self.save_input(f'/tmp/{filename}'))
                 else:
                     continue
             
@@ -466,6 +466,8 @@ if __name__ == "__main__":
     acido = Acido()
     if args.config:
         acido.setup()
+    if args.list_instances:
+        acido.ls(interactive=True)
     if args.shell:
         acido.save_output(args.shell)
     if args.download_input:
